@@ -99,12 +99,46 @@ class Graph:
 
         return self._incoming_nodes[node]
 
+    def incoming_atom_nodes(self, node: t.Union[str, Node]) -> t.AbstractSet[AtomNode]:
+        if isinstance(node, str):
+            node = self._nodes[node]
+
+        incoming_nodes = list(self._incoming_nodes[node])
+        incoming_atom_nodes = set()
+
+        while incoming_nodes:
+            incoming_node = incoming_nodes.pop()
+
+            if isinstance(incoming_node, AtomNode):
+                incoming_atom_nodes.add(incoming_node)
+            else:
+                incoming_nodes.extend(self._incoming_nodes[incoming_node])
+
+        return incoming_atom_nodes
+
     def outgoing_nodes(self, node: t.Union[str, Node]) -> t.AbstractSet[Node]:
         if isinstance(node, str):
             node = self._nodes[node]
 
         return self._outgoing_nodes[node]
 
+    def outgoing_atom_nodes(self, node: t.Union[str, Node]) -> t.AbstractSet[AtomNode]:
+        if isinstance(node, str):
+            node = self._nodes[node]
+
+        outgoing_nodes = list(self._outgoing_nodes[node])
+        outgoing_atom_nodes = set()
+
+        while outgoing_nodes:
+            outgoing_node = outgoing_nodes.pop()
+
+            if isinstance(outgoing_node, AtomNode):
+                outgoing_atom_nodes.add(outgoing_node)
+            else:
+                outgoing_nodes.extend(self._outgoing_nodes[outgoing_node])
+
+        return outgoing_atom_nodes
+
     def incoming_edges(self, node: t.Union[str, Node]) -> t.AbstractSet[Edge]:
         if isinstance(node, str):
             node = self._nodes[node]
@@ -117,6 +151,21 @@ class Graph:
 
         return self._outgoing_edges[node]
 
+    def scheme_between(
+        self, premise: AtomNode, claim: AtomNode
+    ) -> t.Optional[SchemeNode]:
+        candidates = set(self._outgoing_nodes[premise]).intersection(
+            self._incoming_nodes[claim]
+        )
+
+        if len(candidates) == 1:
+            scheme = next(iter(candidates))
+
+            if isinstance(scheme, SchemeNode):
+                return scheme
+
+        return None
+
     @property
     def resources(self) -> t.Mapping[str, Resource]:
         return self._resources
@@ -190,16 +239,17 @@ class Graph:
             node: Node object that is not already part of the graph.
 
         Examples:
-            >>> g = Graph("Test")
-            >>> g.add_node(Node(g.idgen(), "Node", NodeCategory.I))
+            >>> import arguebuf
+            >>> g = arguebuf.Graph("Test")
+            >>> g.add_node(arguebuf.AtomNode("Node"))
             >>> len(g.nodes)
             1
-            >>> g.add_node(Node(1, "Node", NodeCategory.I))
-            Traceback (most recent call last):
-            ValueError: ID already used in graph.
+            >>> g.add_node(arguebuf.SchemeNode(arguebuf.SchemeType.SUPPORT))
+            >>> len(g.nodes)
+            2
             >>> g.add_node("Test")
             Traceback (most recent call last):
-            TypeError: Only Node objects possible.
+            TypeError: Expected type '<class 'arguebuf.node.Node'>', but got '<class 'str'>'. Make sure that you are passing the correct method arguments.
         """
 
         if not isinstance(node, Node):
@@ -231,10 +281,11 @@ class Graph:
             node: Node object that is part of the graph.
 
         Examples:
-            >>> g = Graph("")
-            >>> n1 = Node(g.idgen(), "Node 1", NodeCategory.I)
-            >>> n2 = Node(g.idgen(), "Node 2", NodeCategory.I)
-            >>> e = Edge(g.idgen(), n1, n2)
+            >>> import arguebuf
+            >>> g = Graph("Test")
+            >>> n1 = arguebuf.AtomNode("Node1")
+            >>> n2 = arguebuf.AtomNode("Node2")
+            >>> e = arguebuf.Edge(n1, n2)
             >>> g.add_edge(e)
             >>> len(g.nodes)
             2
@@ -276,20 +327,21 @@ class Graph:
         """Add an edge and its nodes (if not already added).
 
         Args:
-            edge: Edge object that is part of the graph.
+            edge: Edge object that is not part of the graph.
 
         Examples:
-            >>> g = Graph("")
-            >>> n1 = Node(g.idgen(), "Node 1", NodeCategory.I)
-            >>> n2 = Node(g.idgen(), "Node 2", NodeCategory.I)
-            >>> n3 = Node(g.idgen(), "Node 3", NodeCategory.I)
-            >>> e1 = Edge(g.idgen(), n1, n2)
-            >>> e2 = Edge(g.idgen(), n2, n3)
+            >>> import arguebuf
+            >>> g = arguebuf.Graph("Test")
+            >>> n1 = arguebuf.AtomNode("Node1")
+            >>> n2 = arguebuf.AtomNode("Node2")
+            >>> n3 = arguebuf.AtomNode("Node3")
+            >>> e1 = arguebuf.Edge(n1, n2)
+            >>> e2 = arguebuf.Edge(n2, n3)
             >>> g.add_edge(e1)
-            >>> print(len(g.edges))
+            >>> len(g.edges)
             1
             >>> g.add_edge(e2)
-            >>> print(len(g.edges))
+            >>> len(g.edges)
             2
         """
         if not isinstance(edge, Edge):
@@ -318,10 +370,11 @@ class Graph:
             edge: Edge object that is part of the graph.
 
         Examples:
-            >>> g = Graph("")
-            >>> n1 = Node(g.idgen(), "Node 1", NodeCategory.I)
-            >>> n2 = Node(g.idgen(), "Node 2", NodeCategory.I)
-            >>> e = Edge(g.idgen(), n1, n2)
+            >>> import arguebuf
+            >>> g = arguebuf.Graph("Test")
+            >>> n1 = arguebuf.AtomNode("Node1")
+            >>> n2 = arguebuf.AtomNode("Node2")
+            >>> e = arguebuf.Edge(n1, n2)
             >>> g.add_edge(e)
             >>> len(g.edges)
             1
@@ -346,7 +399,21 @@ class Graph:
         self._outgoing_nodes[edge.source]._store.remove(edge.target)
         self._incoming_nodes[edge.target]._store.remove(edge.source)
 
+    ##What does a Resource look like?
     def add_resource(self, resource: Resource) -> None:
+        """Add a resource.
+
+        Args:
+            resource: Resource object that is not part of the graph.
+
+        Examples:
+            >>> import arguebuf
+            >>> g = arguebuf.Graph("Test")
+            >>> r1 = arguebuf.Resource("Resource1")
+            >>> g.add_resource(r1)
+            >>> len(g.resources)
+            1
+        """
         if not isinstance(resource, Resource):
             raise TypeError(utils.type_error(type(resource), Resource))
 
@@ -356,6 +423,22 @@ class Graph:
         self._resources._store[resource.id] = resource
 
     def remove_resource(self, resource: Resource) -> None:
+        """Add a resource.
+
+        Args:
+            resource: Resource object that is part of the graph.
+
+        Examples:
+            >>> import arguebuf
+            >>> g = arguebuf.Graph("Test")
+            >>> r1 = arguebuf.Resource("Resource1")
+            >>> g.add_resource(r1)
+            >>> len(g.resources)
+            1
+            >>> g.remove_resource(r1)
+            >>> len(g.resources)
+            0
+        """
         if not isinstance(resource, Resource):
             raise TypeError(utils.type_error(type(resource), Resource))
 
@@ -370,6 +453,19 @@ class Graph:
                 node.reference.offset = None
 
     def add_participant(self, participant: Participant) -> None:
+        """Add a resource.
+
+        Args:
+            participant: Participant object that is not part of the graph.
+
+        Examples:
+            >>> import arguebuf
+            >>> g = arguebuf.Graph("Test")
+            >>> p1 = arguebuf.Participant("Participant1")
+            >>> g.add_participant(p1)
+            >>> len(g.participants)
+            1
+        """
         if not isinstance(participant, Participant):
             raise TypeError(utils.type_error(type(participant), Participant))
 
@@ -379,6 +475,22 @@ class Graph:
         self._participants._store[participant.id] = participant
 
     def remove_participant(self, participant: Participant) -> None:
+        """Add a resource.
+
+        Args:
+            participant: Participant object that is part of the graph.
+
+        Examples:
+            >>> import arguebuf
+            >>> g = arguebuf.Graph("Test")
+            >>> p1 = arguebuf.Participant("Participant1")
+            >>> g.add_participant(p1)
+            >>> len(g.participants)
+            1
+            >>> g.remove_participant(p1)
+            >>> len(g.participants)
+            0
+        """
         if not isinstance(participant, Participant):
             raise TypeError(utils.type_error(type(participant), Participant))
 
@@ -391,12 +503,37 @@ class Graph:
             if node.participant == participant:
                 node.participant = None
 
+    # Muss man hier nicht auch noch den zweiten Node als Node Objekt definieren?
     def node_distance(self, node1: Node, node2) -> t.Optional[int]:
-        """If node is in the graph, return the distance to the major claim (if set)."""
+        """If node is in the graph, return the distance to the major claim (if set).
+
+        Args:
+            node1: Node object that is part of the graph.
+            node2: Node object that is part of the graph.
+
+        Examples:
+            >>> import arguebuf
+            >>> g = arguebuf.Graph("Test")
+            >>> n1 = arguebuf.AtomNode("Node1")
+            >>> n2 = arguebuf.AtomNode("Node2")
+            >>> n3 = arguebuf.AtomNode("Node3")
+            >>> e1 = arguebuf.Edge(n1, n2)
+            >>> e2 = arguebuf.Edge(n2, n3)
+            >>> g.add_node(n1)
+            >>> g.add_node(n2)
+            >>> len(g.nodes)
+            2
+            >>> g.add_edge(e1)
+            >>> g.add_edge(e2)
+            >>> len(g.edges)
+            2
+            >>> g.node_distance(n1, n3)
+            2
+        """
 
         # TODO: Currently, there is no differentiation between I-nodes and S-nodes.
 
-        if node1 in self.nodes and node2 in self.nodes:
+        if node1 in self.nodes.values() and node2 in self.nodes.values():
             if node1 == node2:
                 return 0
 
@@ -424,7 +561,6 @@ class Graph:
         # g.metadata = utils.parse_metadata(obj, include=["participants", "ovaVersion"])
 
         resource = Resource(
-            utils.unique_id(),
             utils.parse(analysis.get("plain_txt"), nlp),
             analysis.get("documentTitle"),
             analysis.get("documentSource"),
@@ -433,7 +569,7 @@ class Graph:
         g.add_resource(resource)
 
         if analyst_name := analysis.get("annotatorName"):
-            g.analysts.append(Participant(utils.unique_id(), name=analyst_name))
+            g.analysts.append(Participant(name=analyst_name))
 
         for ova_node in obj["nodes"]:
             node = (
@@ -522,6 +658,7 @@ class Graph:
         }
 
     def to_protobuf(self) -> graph_pb2.Graph:
+        """Export structure of Graph instance to PROTOBUF argument graph format."""
         g = graph_pb2.Graph()
 
         for node_id, node in self._nodes.items():
@@ -562,6 +699,7 @@ class Graph:
         reference_class: t.Type[Reference] = Reference,
         nlp: t.Optional[t.Callable[[str], t.Any]] = None,
     ) -> Graph:
+        """Generate Graph structure from PROTOBUF argument graph file.(Link?)"""
         g = cls(name)
 
         for resource_id, resource in obj.resources.items():
@@ -624,6 +762,7 @@ class Graph:
         edge_class: t.Type[Edge] = Edge,
         nlp: t.Optional[t.Callable[[str], t.Any]] = None,
     ) -> Graph:
+        """Generate Graph structure from DICT argument graph file(Link?)."""
         if "analysis" in obj:
             return cls.from_ova(obj, name, atom_class, scheme_class, edge_class, nlp)
 
@@ -640,6 +779,8 @@ class Graph:
         )
 
     def to_dict(self, format: GraphFormat) -> t.Dict[str, t.Any]:
+        """Export structure of Graph instance to DICT argument graph format."""
+
         if format == GraphFormat.AIF:
             return self.to_aif()
 
@@ -655,6 +796,7 @@ class Graph:
         edge_class: t.Type[Edge] = Edge,
         nlp: t.Optional[t.Callable[[str], t.Any]] = None,
     ) -> Graph:
+        """Generate Graph structure from JSON argument graph file(Link?)."""
         return cls.from_dict(
             json.load(obj), name, atom_class, scheme_class, edge_class, nlp
         )
@@ -665,6 +807,7 @@ class Graph:
         format: GraphFormat = GraphFormat.ARGUEBUF,
         pretty: bool = False,
     ) -> None:
+        """Export structure of Graph instance to JSON argument graph format."""
         json.dump(
             self.to_dict(format), obj, ensure_ascii=False, indent=4 if pretty else None
         )
@@ -679,12 +822,12 @@ class Graph:
         edge_class: t.Type[Edge] = Edge,
         nlp: t.Optional[t.Callable[[str], t.Any]] = None,
     ) -> Graph:
-        """Generate Graph structure from brat argument graph file (reference: https://brat.nlplab.org/)"""
+        """Generate Graph structure from BRAT argument graph file (reference: https://brat.nlplab.org/)"""
         reader = csv.reader(obj, delimiter="\t")
         g = cls(name)
 
         inodes = {}
-        mc = atom_class(utils.unique_id(), utils.parse("", nlp))
+        mc = atom_class(utils.parse("", nlp))
         g.add_node(mc)
         g._major_claim = mc
 
@@ -695,7 +838,7 @@ class Graph:
                 if metadata[0] == "MajorClaim":
                     mc.text = utils.parse(mc.plain_text + ". " + row[2], nlp)
                 else:
-                    inode = atom_class(utils.unique_id(), utils.parse(row[2], nlp))
+                    inode = atom_class(utils.parse(row[2], nlp))
                     g.add_node(inode)
                     inodes[row[0]] = inode
 
@@ -717,11 +860,11 @@ class Graph:
                     source_inode = inodes[metadata[1].split(":")[1]]
                     target_inode = inodes[metadata[2].split(":")[1]]
 
-                snode = scheme_class(utils.unique_id(), scheme_type)
+                snode = scheme_class(scheme_type)
                 g.add_node(snode)
 
-                g.add_edge(edge_class(utils.unique_id(), source_inode, snode))
-                g.add_edge(edge_class(utils.unique_id(), snode, target_inode))
+                g.add_edge(edge_class(source_inode, snode))
+                g.add_edge(edge_class(snode, target_inode))
 
         return g
 
@@ -736,6 +879,7 @@ class Graph:
         edge_class: t.Type[Edge] = Edge,
         nlp: t.Optional[t.Callable[[str], t.Any]] = None,
     ) -> Graph:
+        """Generate Graph structure from IO argument graph file(Link?)."""
         if suffix == ".ann":
             return cls.from_brat(obj, name, atom_class, scheme_class, edge_class, nlp)
 
@@ -747,6 +891,7 @@ class Graph:
         format: GraphFormat = GraphFormat.ARGUEBUF,
         pretty: bool = False,
     ) -> None:
+        """Export structure of Graph instance to IO argument graph format."""
         self.to_json(obj, format, pretty)
 
     @classmethod
@@ -758,6 +903,7 @@ class Graph:
         edge_class: t.Type[Edge] = Edge,
         nlp: t.Optional[t.Callable[[str], t.Any]] = None,
     ) -> Graph:
+        """Generate Graph structure from a File."""
         with path.open("r", encoding="utf-8") as file:
             return cls.from_io(
                 file, path.suffix, path.stem, atom_class, scheme_class, edge_class, nlp
@@ -769,6 +915,7 @@ class Graph:
         format: GraphFormat = GraphFormat.ARGUEBUF,
         pretty: bool = False,
     ) -> None:
+        """Export strucure of Graph instance into structure of File/Folder format."""
         if path.is_dir() or not path.suffix:
             path = path / f"{self.name}.json"
 
@@ -787,6 +934,7 @@ class Graph:
         nlp: t.Optional[t.Callable[[str], t.Any]] = None,
         suffixes: t.Iterable[str] = (".json"),
     ) -> t.List[Graph]:
+        "Generate Graph structure from Folder."
         graphs = []
 
         for suffix in suffixes:
@@ -801,10 +949,11 @@ class Graph:
         """Transform a Graph instance into an instance of networkx directed graph. Refer to the networkx library for additional information.
 
         Examples:
-            >>> g = Graph("")
-            >>> n1 = Node(g.idgen(), "Node 1", NodeCategory.I)
-            >>> n2 = Node(g.idgen(), "Node 2", NodeCategory.I)
-            >>> e = Edge(g.idgen(), n1, n2)
+            >>> import arguebuf
+            >>> g = Graph("Test")
+            >>> n1 = arguebuf.AtomNode("Node1")
+            >>> n2 = arguebuf.AtomNode("Node2")
+            >>> e = arguebuf.Edge(n1, n2)
             >>> g.add_edge(e)
             >>> gnx = g.to_nx()
             >>> gnx.number_of_nodes()
@@ -897,9 +1046,9 @@ class Graph:
                 ):
                     self.add_edge(
                         Edge(
-                            f"{incoming.id}-{outgoing.id}",
                             incoming.source,
                             outgoing.target,
+                            id=f"{incoming.id}-{outgoing.id}",
                         )
                     )
 
